pub enum SyncAction {
InsertEdge {
source: u32,
target: u32,
},
RemoveOverlayEdge {
source: u32,
target: u32,
},
DeleteEdge {
edge_id: u32,
},
DeleteNode {
node_id: u32,
},
TruncateOverlays,
}Expand description
One durable sync row interpreted by the library.
Variants
InsertEdge
Insert a new overlay edge between dense node ids.
RemoveOverlayEdge
Remove a previously inserted overlay edge between dense node ids.
DeleteEdge
Tombstone a base edge id.
DeleteNode
Tombstone a node id from query results.
TruncateOverlays
Truncate all overlays (maintenance prelude).