pub fn estimate_build(edges: &[EdgeRow]) -> BuildEstimateExpand description
Estimates node and edge counts for a build without exporting a snapshot.
Performance
This function is O(m).
pub fn estimate_build(edges: &[EdgeRow]) -> BuildEstimateEstimates node and edge counts for a build without exporting a snapshot.
This function is O(m).